searchData={"items":[{"type":"module","title":"Igniter","doc":"Tools for generating and patching code into an Elixir project.","ref":"Igniter.html"},{"type":"function","title":"Igniter.add_issue/2","doc":"Adds an issue to the issues list. Any issues will prevent writing and be displayed to the user.","ref":"Igniter.html#add_issue/2"},{"type":"function","title":"Igniter.add_task/3","doc":"Adds a task to the tasks list. Tasks will be run after all changes have been commited","ref":"Igniter.html#add_task/3"},{"type":"function","title":"Igniter.add_warning/2","doc":"Adds a warning to the warnings list. Warnings will not prevent writing, but will be displayed to the user.","ref":"Igniter.html#add_warning/2"},{"type":"function","title":"Igniter.apply_and_fetch_dependencies/2","doc":"Applies the current changes to the `mix.exs` in the Igniter and fetches dependencies.\n\nReturns the remaining changes in the Igniter if successful.","ref":"Igniter.html#apply_and_fetch_dependencies/2"},{"type":"function","title":"Options - Igniter.apply_and_fetch_dependencies/2","doc":"* `:error_on_abort?` - If `true`, raises an error if the user aborts the operation. Returns the original igniter if not.\n* `:yes` - If `true`, automatically applies the changes without prompting the user.","ref":"Igniter.html#apply_and_fetch_dependencies/2-options"},{"type":"function","title":"Igniter.assign/2","doc":"","ref":"Igniter.html#assign/2"},{"type":"function","title":"Igniter.assign/3","doc":"Stores the key/value pair in `igniter.assigns`","ref":"Igniter.html#assign/3"},{"type":"function","title":"Igniter.compose_task/4","doc":"Finds the `Igniter.Mix.Task` task by name and composes it (calls its `igniter/2`) into the current igniter.\nIf the task doesn't exist, a fallback implementation may be provided as the last argument.","ref":"Igniter.html#compose_task/4"},{"type":"function","title":"Igniter.create_new_elixir_file/3","doc":"Creates a new elixir file in the project with the provided string contents. Adds an error if it already exists.","ref":"Igniter.html#create_new_elixir_file/3"},{"type":"function","title":"Igniter.create_or_update_elixir_file/4","doc":"Creates the given file in the project with the provided string contents, or updates it with a function of type `zipper_updater()` if it already exists.","ref":"Igniter.html#create_or_update_elixir_file/4"},{"type":"function","title":"Igniter.do_or_dry_run/2","doc":"Executes or dry-runs a given Igniter.","ref":"Igniter.html#do_or_dry_run/2"},{"type":"function","title":"Igniter.exists?/2","doc":"","ref":"Igniter.html#exists?/2"},{"type":"function","title":"Igniter.has_changes?/2","doc":"Returns whether the current Igniter has pending changes.","ref":"Igniter.html#has_changes?/2"},{"type":"function","title":"Igniter.include_all_elixir_files/1","doc":"This function stores in the igniter if its been run before, so it is only run once, which is expensive.","ref":"Igniter.html#include_all_elixir_files/1"},{"type":"function","title":"Igniter.include_existing_elixir_file/3","doc":"Includes the given elixir file in the project, expecting it to exist. Does nothing if its already been added.","ref":"Igniter.html#include_existing_elixir_file/3"},{"type":"function","title":"Igniter.include_existing_file/3","doc":"Includes the given file in the project, expecting it to exist. Does nothing if its already been added.","ref":"Igniter.html#include_existing_file/3"},{"type":"function","title":"Igniter.include_glob/2","doc":"Includes all files matching the given glob, expecting them all (for now) to be elixir files.","ref":"Igniter.html#include_glob/2"},{"type":"function","title":"Igniter.include_or_create_elixir_file/3","doc":"Includes or creates the given file in the project with the provided contents. Does nothing if its already been added.","ref":"Igniter.html#include_or_create_elixir_file/3"},{"type":"function","title":"Igniter.move_file/4","doc":"","ref":"Igniter.html#move_file/4"},{"type":"function","title":"Igniter.new/0","doc":"Returns a new igniter","ref":"Igniter.html#new/0"},{"type":"function","title":"Igniter.update_assign/4","doc":"","ref":"Igniter.html#update_assign/4"},{"type":"function","title":"Igniter.update_elixir_file/3","doc":"Updates the source code of the given elixir file","ref":"Igniter.html#update_elixir_file/3"},{"type":"function","title":"Igniter.update_file/3","doc":"Updates a given file's `Rewrite.Source`","ref":"Igniter.html#update_file/3"},{"type":"function","title":"Igniter.update_glob/3","doc":"Updates all files matching the given glob with the given zipper function.\n\nAdds any new files matching that glob to the igniter first.","ref":"Igniter.html#update_glob/3"},{"type":"type","title":"Igniter.t/0","doc":"","ref":"Igniter.html#t:t/0"},{"type":"type","title":"Igniter.zipper_updater/0","doc":"","ref":"Igniter.html#t:zipper_updater/0"},{"type":"module","title":"Igniter.Code.Common","doc":"General purpose utilities for working with `Sourceror.Zipper`.","ref":"Igniter.Code.Common.html"},{"type":"function","title":"Igniter.Code.Common.add_code/3","doc":"Adds the provided code to the zipper.\n\nUse `placement` to determine if the code goes `:after` or `:before` the current node.","ref":"Igniter.Code.Common.html#add_code/3"},{"type":"function","title":"Example: - Igniter.Code.Common.add_code/3","doc":"```elixir\nexisting_zipper = \"\"\"\nIO.inspect(\"Hello, world!\")\n\"\"\"\n|> Sourceror.parse_string!()\n|> Sourceror.Zipper.zip()\n\nnew_code = \"\"\"\nIO.inspect(\"Goodbye, world!\")\n\"\"\"\n\nexisting_zipper\n|> Igniter.Common.add_code(new_code)\n|> Sourceror.Zipper.root()\n|> Sourceror.to_string()\n```\n\nWhich will produce\n\n```elixir\n\"\"\"\nIO.inspect(\"Hello, world!\")\nIO.inspect(\"Goodbye, world!\")\n\"\"\"\n```","ref":"Igniter.Code.Common.html#add_code/3-example"},{"type":"function","title":"Igniter.Code.Common.current_env/1","doc":"Expands the environment at the current zipper position and returns the\nexpanded environment. Currently used for properly working with aliases.","ref":"Igniter.Code.Common.html#current_env/1"},{"type":"function","title":"Igniter.Code.Common.expand_alias/1","doc":"","ref":"Igniter.Code.Common.html#expand_alias/1"},{"type":"function","title":"Igniter.Code.Common.expand_aliases/1","doc":"","ref":"Igniter.Code.Common.html#expand_aliases/1"},{"type":"function","title":"Igniter.Code.Common.maybe_move_to_block/1","doc":"Enters a block, and moves to the first child, or returns the zipper unmodified.","ref":"Igniter.Code.Common.html#maybe_move_to_block/1"},{"type":"function","title":"Igniter.Code.Common.maybe_move_to_single_child_block/1","doc":"Enters a block with a single child, and moves to that child,\nor returns the zipper unmodified","ref":"Igniter.Code.Common.html#maybe_move_to_single_child_block/1"},{"type":"function","title":"Igniter.Code.Common.move_next/2","doc":"Moves nextwards (depth-first), until the provided predicate returns `true`.\n\nReturns `:error` if the end is reached without finding a match.","ref":"Igniter.Code.Common.html#move_next/2"},{"type":"function","title":"Igniter.Code.Common.move_right/2","doc":"Moves rightwards, entering blocks (and exiting them if no match is found), until the provided predicate returns `true`.\n\nReturns `:error` if the end is reached without finding a match.","ref":"Igniter.Code.Common.html#move_right/2"},{"type":"function","title":"Igniter.Code.Common.move_to/2","doc":"Moves to the next node that matches the predicate.","ref":"Igniter.Code.Common.html#move_to/2"},{"type":"function","title":"Igniter.Code.Common.move_to_cursor/2","doc":"Matches and moves to the location of a `__cursor__` in provided source code.\n\nUse `__cursor__()` to match a cursor in the provided source code. Use `__` to skip any code at a point.\n\nFor example:\n\n```elixir\nzipper =\n  \"\"\"\n  if true do\n    10\n  end\n  \"\"\"\n  |> Sourceror.Zipper.zip()\n\npattern =\n  \"\"\"\n  if __ do\n    __cursor__\n  end\n  \"\"\"\n\nzipper\n|> Igniter.Code.Common.move_to_cursor(pattern)\n|> Zipper.subtree()\n|> Zipper.node()\n# => 10\n```","ref":"Igniter.Code.Common.html#move_to_cursor/2"},{"type":"function","title":"Igniter.Code.Common.move_to_cursor_match_in_scope/2","doc":"Moves to the cursor that matches the provided pattern or one of the provided patterns, in the current scope.\n\nSee `move_to_cursor/2` for an example of a pattern","ref":"Igniter.Code.Common.html#move_to_cursor_match_in_scope/2"},{"type":"function","title":"Igniter.Code.Common.move_to_do_block/1","doc":"Moves to a do block for the current call.\n\nFor example, at a node like:\n\n```elixir\nfoo do\n  10\nend\n```\n\nYou would get a zipper back at `10`.","ref":"Igniter.Code.Common.html#move_to_do_block/1"},{"type":"macro","title":"Igniter.Code.Common.move_to_pattern/2","doc":"Moves to the next node that matches the given pattern.","ref":"Igniter.Code.Common.html#move_to_pattern/2"},{"type":"function","title":"Igniter.Code.Common.move_to_zipper/2","doc":"Moves to the next zipper that matches the predicate.","ref":"Igniter.Code.Common.html#move_to_zipper/2"},{"type":"macro","title":"Igniter.Code.Common.node_matches_pattern?/2","doc":"Returns `true` if the current node matches the given pattern.","ref":"Igniter.Code.Common.html#node_matches_pattern?/2"},{"type":"macro","title":"Examples: - Igniter.Code.Common.node_matches_pattern?/2","doc":"```elixir\nlist_zipper =\n  \"[1, 2, 3]\"\n  |> Sourceror.parse_string!()\n  |> Sourceror.Zipper.zip()\n\nCommon.node_matches_pattern?(list_zipper, value when is_list(value)) # true\n```","ref":"Igniter.Code.Common.html#node_matches_pattern?/2-examples"},{"type":"function","title":"Igniter.Code.Common.nodes_equal?/2","doc":"","ref":"Igniter.Code.Common.html#nodes_equal?/2"},{"type":"function","title":"Igniter.Code.Common.nth_right/2","doc":"Moves the zipper right n times, returning `:error` if it can't move that many times.","ref":"Igniter.Code.Common.html#nth_right/2"},{"type":"function","title":"Igniter.Code.Common.replace_code/2","doc":"","ref":"Igniter.Code.Common.html#replace_code/2"},{"type":"function","title":"Igniter.Code.Common.rightmost/1","doc":"Moves the zipper all the way to the right, potentially entering a single value block.","ref":"Igniter.Code.Common.html#rightmost/1"},{"type":"function","title":"Igniter.Code.Common.use_aliases/2","doc":"","ref":"Igniter.Code.Common.html#use_aliases/2"},{"type":"function","title":"Igniter.Code.Common.within/2","doc":"Runs the function `fun` on the subtree of the currently focused `node` and\nreturns the updated `zipper`.\n\n`fun` must return {:ok, zipper} or `:error`, which may be positioned at the top of the subtree.","ref":"Igniter.Code.Common.html#within/2"},{"type":"module","title":"Igniter.Code.Function","doc":"Utilities for working with functions.","ref":"Igniter.Code.Function.html"},{"type":"function","title":"Igniter.Code.Function.append_argument/2","doc":"Appends an argument to a function call, leaving the zipper at the function call's node.","ref":"Igniter.Code.Function.html#append_argument/2"},{"type":"macro","title":"Igniter.Code.Function.argument_matches_pattern?/3","doc":"Returns `true` if the argument at the provided index exists and matches the provided pattern","ref":"Igniter.Code.Function.html#argument_matches_pattern?/3"},{"type":"function","title":"Igniter.Code.Function.argument_matches_predicate?/3","doc":"Returns true if the argument at the given index matches the provided predicate","ref":"Igniter.Code.Function.html#argument_matches_predicate?/3"},{"type":"function","title":"Igniter.Code.Function.function_call?/1","doc":"Returns `true` if the node is a function call","ref":"Igniter.Code.Function.html#function_call?/1"},{"type":"function","title":"Igniter.Code.Function.function_call?/2","doc":"Returns `true` if the node is a function call of the given name","ref":"Igniter.Code.Function.html#function_call?/2"},{"type":"function","title":"Igniter.Code.Function.function_call?/3","doc":"Returns `true` if the node is a function call of the given name and arity","ref":"Igniter.Code.Function.html#function_call?/3"},{"type":"function","title":"Igniter.Code.Function.move_to_function_call/4","doc":"Moves to a function call by the given name and arity, matching the given predicate, in the current or lower scope","ref":"Igniter.Code.Function.html#move_to_function_call/4"},{"type":"function","title":"Igniter.Code.Function.move_to_function_call_in_current_scope/4","doc":"Moves to a function call by the given name and arity, matching the given predicate, in the current scope","ref":"Igniter.Code.Function.html#move_to_function_call_in_current_scope/4"},{"type":"function","title":"Igniter.Code.Function.move_to_nth_argument/2","doc":"Moves to the `nth` argument of a function call.","ref":"Igniter.Code.Function.html#move_to_nth_argument/2"},{"type":"function","title":"Igniter.Code.Function.update_nth_argument/3","doc":"Updates the `nth` argument of a function call, leaving the zipper at the function call's node.","ref":"Igniter.Code.Function.html#update_nth_argument/3"},{"type":"module","title":"Igniter.Code.Keyword","doc":"Utilities for working with keyword.","ref":"Igniter.Code.Keyword.html"},{"type":"function","title":"Igniter.Code.Keyword.get_key/2","doc":"Returns true if the node is a nested keyword list containing a value at the given path.","ref":"Igniter.Code.Keyword.html#get_key/2"},{"type":"function","title":"Igniter.Code.Keyword.keyword_has_path?/2","doc":"Returns true if the node is a nested keyword list containing a value at the given path.","ref":"Igniter.Code.Keyword.html#keyword_has_path?/2"},{"type":"function","title":"Igniter.Code.Keyword.keywordify/2","doc":"Puts into nested keyword lists represented by `path`","ref":"Igniter.Code.Keyword.html#keywordify/2"},{"type":"function","title":"Igniter.Code.Keyword.put_in_keyword/4","doc":"Puts a value at a path into a keyword, calling `updater` on the zipper at the value if the key is already present","ref":"Igniter.Code.Keyword.html#put_in_keyword/4"},{"type":"function","title":"Igniter.Code.Keyword.remove_keyword_key/2","doc":"Removes a key from a keyword list if present. Returns `:error` only if the node is not a list","ref":"Igniter.Code.Keyword.html#remove_keyword_key/2"},{"type":"function","title":"Igniter.Code.Keyword.set_keyword_key/4","doc":"","ref":"Igniter.Code.Keyword.html#set_keyword_key/4"},{"type":"module","title":"Igniter.Code.List","doc":"Utilities for working with lists.","ref":"Igniter.Code.List.html"},{"type":"function","title":"Igniter.Code.List.append_new_to_list/3","doc":"Appends `quoted` to the list unless it is already present, determined by `equality_pred`.","ref":"Igniter.Code.List.html#append_new_to_list/3"},{"type":"function","title":"Igniter.Code.List.append_to_list/2","doc":"Appends `quoted` to the list","ref":"Igniter.Code.List.html#append_to_list/2"},{"type":"function","title":"Igniter.Code.List.find_list_item_index/2","doc":"Finds the index of the first list item that satisfies `pred`","ref":"Igniter.Code.List.html#find_list_item_index/2"},{"type":"function","title":"Igniter.Code.List.list?/1","doc":"Returns true if the `zipper` is at a list literal","ref":"Igniter.Code.List.html#list?/1"},{"type":"function","title":"Igniter.Code.List.move_to_list_item/2","doc":"Moves to the list item matching the given predicate","ref":"Igniter.Code.List.html#move_to_list_item/2"},{"type":"function","title":"Igniter.Code.List.prepend_new_to_list/3","doc":"Prepends `quoted` to the list unless it is already present, determined by `equality_pred`.","ref":"Igniter.Code.List.html#prepend_new_to_list/3"},{"type":"function","title":"Igniter.Code.List.prepend_to_list/2","doc":"Prepends `quoted` to the list","ref":"Igniter.Code.List.html#prepend_to_list/2"},{"type":"function","title":"Igniter.Code.List.remove_from_list/2","doc":"","ref":"Igniter.Code.List.html#remove_from_list/2"},{"type":"function","title":"Igniter.Code.List.remove_index/2","doc":"Removes the item at the given index, returning `:error` if nothing is at that index","ref":"Igniter.Code.List.html#remove_index/2"},{"type":"type","title":"Igniter.Code.List.equality_pred/0","doc":"","ref":"Igniter.Code.List.html#t:equality_pred/0"},{"type":"module","title":"Igniter.Code.Map","doc":"Utilities for working with maps.","ref":"Igniter.Code.Map.html"},{"type":"function","title":"Igniter.Code.Map.mappify/2","doc":"Puts a value into nested maps at the given path","ref":"Igniter.Code.Map.html#mappify/2"},{"type":"function","title":"Igniter.Code.Map.put_in_map/4","doc":"Puts a value at a path into a map, calling `updater` on the zipper at the value if the key is already present","ref":"Igniter.Code.Map.html#put_in_map/4"},{"type":"function","title":"Igniter.Code.Map.set_map_key/4","doc":"Puts a key into a map, calling `updater` on the zipper at the value if the key is already present","ref":"Igniter.Code.Map.html#set_map_key/4"},{"type":"module","title":"Igniter.Code.Module","doc":"Utilities for working with Elixir modules","ref":"Igniter.Code.Module.html"},{"type":"function","title":"Igniter.Code.Module.find_all_matching_modules/2","doc":"","ref":"Igniter.Code.Module.html#find_all_matching_modules/2"},{"type":"function","title":"Igniter.Code.Module.find_and_update_module/3","doc":"Finds a module and updates its contents. Returns `{:error, igniter}` if the module could not be found. Do not discard this igniter.","ref":"Igniter.Code.Module.html#find_and_update_module/3"},{"type":"function","title":"Igniter.Code.Module.find_and_update_module!/3","doc":"","ref":"Igniter.Code.Module.html#find_and_update_module!/3"},{"type":"function","title":"Igniter.Code.Module.find_and_update_or_create_module/5","doc":"Finds a module and updates its contents wherever it is.\n\nIf the module does not yet exist, it is created with the provided contents. In that case,\nthe path is determined with `Igniter.Code.Module.proper_location/2`, but may optionally be overwritten with options below.\n\n# Options\n\n- `:path` - Path where to create the module, relative to the project root. Default: `nil` (uses `:kind` to determine the path).\n- `:kind` - Type of module being created. Possible values: `:lib`, `:test`, `:test_support` (default: `:lib`). Ignored if `:path` is set.","ref":"Igniter.Code.Module.html#find_and_update_or_create_module/5"},{"type":"function","title":"Igniter.Code.Module.find_module/2","doc":"Finds a module, returning a new igniter, and the source and zipper location. This new igniter should not be discarded.\n\nIn general, you should not use the returned source and zipper to update the module, instead, use this to interrogate\nthe contents or source in some way, and then call `find_and_update_module/3` with a function to perform an update.","ref":"Igniter.Code.Module.html#find_module/2"},{"type":"function","title":"Igniter.Code.Module.module?/1","doc":"","ref":"Igniter.Code.Module.html#module?/1"},{"type":"function","title":"Igniter.Code.Module.module_exists?/2","doc":"Checks if a module is defined somewhere in the project. The returned igniter should not be discarded.","ref":"Igniter.Code.Module.html#module_exists?/2"},{"type":"function","title":"Igniter.Code.Module.module_name/1","doc":"Given a suffix, returns a module name with the prefix of the current project.","ref":"Igniter.Code.Module.html#module_name/1"},{"type":"function","title":"Igniter.Code.Module.module_name_prefix/0","doc":"The module name prefix based on the mix project's module name","ref":"Igniter.Code.Module.html#module_name_prefix/0"},{"type":"function","title":"Igniter.Code.Module.move_to_def/3","doc":"","ref":"Igniter.Code.Module.html#move_to_def/3"},{"type":"function","title":"Igniter.Code.Module.move_to_defmodule/1","doc":"Moves the zipper to a defmodule call","ref":"Igniter.Code.Module.html#move_to_defmodule/1"},{"type":"function","title":"Igniter.Code.Module.move_to_defmodule/2","doc":"Moves the zipper to a specific defmodule call","ref":"Igniter.Code.Module.html#move_to_defmodule/2"},{"type":"function","title":"Igniter.Code.Module.move_to_defp/3","doc":"","ref":"Igniter.Code.Module.html#move_to_defp/3"},{"type":"function","title":"Igniter.Code.Module.move_to_module_using/2","doc":"Moves the zipper to the body of a module that `use`s the provided module (or one of the provided modules).","ref":"Igniter.Code.Module.html#move_to_module_using/2"},{"type":"function","title":"Igniter.Code.Module.move_to_use/2","doc":"Moves the zipper to the `use` statement for a provided module.","ref":"Igniter.Code.Module.html#move_to_use/2"},{"type":"function","title":"Igniter.Code.Module.move_to_using/2","doc":"","ref":"Igniter.Code.Module.html#move_to_using/2"},{"type":"function","title":"Igniter.Code.Module.parse/1","doc":"Parses a string into a module name","ref":"Igniter.Code.Module.html#parse/1"},{"type":"function","title":"Igniter.Code.Module.proper_location/2","doc":"Returns the idiomatic file location for a given module, starting with \"lib/\".\n\nExamples:\n\n  iex> Igniter.Code.Module.proper_location(MyApp.Hello)\n  \"lib/my_app/hello.ex\"","ref":"Igniter.Code.Module.html#proper_location/2"},{"type":"function","title":"Igniter.Code.Module.proper_test_location/1","doc":"Returns the test file location for a given module, according to\n`mix test` expectations, starting with \"test/\" and ending with \"_test.exs\".\n\nExamples:\n\n  iex> Igniter.Code.Module.proper_test_location(MyApp.Hello)\n  \"test/my_app/hello_test.exs\"\n\n  iex> Igniter.Code.Module.proper_test_location(MyApp.HelloTest)\n  \"test/my_app/hello_test.exs\"","ref":"Igniter.Code.Module.html#proper_test_location/1"},{"type":"function","title":"Igniter.Code.Module.proper_test_support_location/1","doc":"Returns the test support location for a given module, starting with\n\"test/support/\" and dropping the module name prefix in the path.\n\nExamples:\n\n  iex> Igniter.Code.Module.proper_test_support_location(MyApp.DataCase)\n  \"test/support/data_case.ex\"","ref":"Igniter.Code.Module.html#proper_test_support_location/1"},{"type":"module","title":"Igniter.Code.Tuple","doc":"Utilities for working with tuples.","ref":"Igniter.Code.Tuple.html"},{"type":"function","title":"Igniter.Code.Tuple.tuple?/1","doc":"Returns `true` if the zipper is at a literal tuple, `false` if not.","ref":"Igniter.Code.Tuple.html#tuple?/1"},{"type":"function","title":"Igniter.Code.Tuple.tuple_elem/2","doc":"Returns a zipper at the tuple element at the given index, or `:error` if the index is out of bounds.","ref":"Igniter.Code.Tuple.html#tuple_elem/2"},{"type":"behaviour","title":"Igniter.Mix.Task","doc":"A behaviour for implementing a Mix task that is enriched to be composable with other Igniter tasks.","ref":"Igniter.Mix.Task.html"},{"type":"callback","title":"Igniter.Mix.Task.igniter/2","doc":"All the generator behavior happens here, you take an igniter and task arguments, and return an igniter.","ref":"Igniter.Mix.Task.html#c:igniter/2"},{"type":"callback","title":"Igniter.Mix.Task.info/2","doc":"Returns an `Igniter.Mix.Task.Info` struct, with information used when running the igniter task.\n\nThis info will be used to validate arguments in composed tasks.","ref":"Igniter.Mix.Task.html#c:info/2"},{"type":"callback","title":"Important Limitations - Igniter.Mix.Task.info/2","doc":"* Each task still must parse its own argv in `igniter/2` and *must* ignore any unknown options.\n  To accomplish this, use the automatically imported `options!(argv)` macro, which uses the `info/2`\n  callback to validate args and return options\n* You cannot use `composes` to list tasks unless they are in your library or in direct dependencies of your library.\n  To validate their options, you must include their options in your own option schema.","ref":"Igniter.Mix.Task.html#c:info/2-important-limitations"},{"type":"macro","title":"Igniter.Mix.Task.options!/1","doc":"","ref":"Igniter.Mix.Task.html#options!/1"},{"type":"callback","title":"Igniter.Mix.Task.supports_umbrella?/0","doc":"Whether or not it supports being run in the root of an umbrella project\n\nAt the moment, this is still experimental and we suggest not turning it on.","ref":"Igniter.Mix.Task.html#c:supports_umbrella?/0"},{"type":"module","title":"Igniter.Mix.Task.Info","doc":"Info for an `Igniter.Mix.Task`, returned from the `info/2` callback","ref":"Igniter.Mix.Task.Info.html"},{"type":"module","title":"Configurable Keys - Igniter.Mix.Task.Info","doc":"* `schema` - The option schema for this task, in the format given to `OptionParser`, i.e `[name: :string]`\n* `aliases` - A map of aliases to the schema keys.\n* `composes` - A list of tasks that this task might compose.\n* `installs` - A list of dependencies that should be installed before continuing.\n* `adds_deps` - A list of dependencies that should be added to the `mix.exs`, but do not need to be installed before continuing.\n* `extra_args?` - Whether or not to allow extra arguments. This forces all tasks that compose this task to allow extra args as well.\n\nYour task should *always* use `switches` and not `strict` to validate provided options!","ref":"Igniter.Mix.Task.Info.html#module-configurable-keys"},{"type":"function","title":"Igniter.Mix.Task.Info.global_options/0","doc":"","ref":"Igniter.Mix.Task.Info.html#global_options/0"},{"type":"type","title":"Igniter.Mix.Task.Info.t/0","doc":"","ref":"Igniter.Mix.Task.Info.html#t:t/0"},{"type":"module","title":"Igniter.Project.Application","doc":"Codemods and tools for working with Application modules.","ref":"Igniter.Project.Application.html"},{"type":"function","title":"Igniter.Project.Application.add_new_child/2","doc":"Adds a new child to the `children` list in the application file","ref":"Igniter.Project.Application.html#add_new_child/2"},{"type":"function","title":"Igniter.Project.Application.app_name/0","doc":"Returns the name of the current application.","ref":"Igniter.Project.Application.html#app_name/0"},{"type":"function","title":"Igniter.Project.Application.create_app/2","doc":"","ref":"Igniter.Project.Application.html#create_app/2"},{"type":"function","title":"Igniter.Project.Application.do_add_child/3","doc":"","ref":"Igniter.Project.Application.html#do_add_child/3"},{"type":"module","title":"Igniter.Project.Config","doc":"Codemods and utilities for modifying Elixir config files.","ref":"Igniter.Project.Config.html"},{"type":"function","title":"Igniter.Project.Config.configure/6","doc":"Sets a config value in the given configuration file, updating it with `updater` if it is already set.","ref":"Igniter.Project.Config.html#configure/6"},{"type":"function","title":"Opts - Igniter.Project.Config.configure/6","doc":"* `:updater` - A function that takes a zipper at a currently configured value and returns a new zipper with the value updated.\n* `failure_message` - A message to display to the user if the configuration change is unsuccessful.","ref":"Igniter.Project.Config.html#configure/6-opts"},{"type":"function","title":"Igniter.Project.Config.configure_new/6","doc":"Sets a config value in the given configuration file, if it is not already set.","ref":"Igniter.Project.Config.html#configure_new/6"},{"type":"function","title":"Opts - Igniter.Project.Config.configure_new/6","doc":"* `failure_message` - A message to display to the user if the configuration change is unsuccessful.","ref":"Igniter.Project.Config.html#configure_new/6-opts"},{"type":"function","title":"Igniter.Project.Config.configures?/3","doc":"Returns `true` if the given configuration path is set somewhere after the provided zipper.","ref":"Igniter.Project.Config.html#configures?/3"},{"type":"function","title":"Igniter.Project.Config.modify_configuration_code/5","doc":"Modifies elixir configuration code starting at the configured zipper.\n\nIf you want to set configuration, use `configure/6` or `configure_new/5` instead. This is a lower-level\ntool for modifying configuration files when you need to adjust some specific part of them.","ref":"Igniter.Project.Config.html#modify_configuration_code/5"},{"type":"module","title":"Igniter.Project.Deps","doc":"Codemods and utilities for managing dependencies declared in mix.exs","ref":"Igniter.Project.Deps.html"},{"type":"function","title":"Igniter.Project.Deps.add_dep/3","doc":"Adds a dependency to the mix.exs file.\n\n# Options\n\n- `:yes?` - Automatically answer yes to any prompts.\n- `:append?` - Append to the dependency list instead of prepending.\n- `:error?` - Returns an error instead of a notice on failure.","ref":"Igniter.Project.Deps.html#add_dep/3"},{"type":"function","title":"Igniter.Project.Deps.add_dependency/4","doc":"","ref":"Igniter.Project.Deps.html#add_dependency/4"},{"type":"function","title":"Igniter.Project.Deps.get_dependency_declaration/2","doc":"","ref":"Igniter.Project.Deps.html#get_dependency_declaration/2"},{"type":"module","title":"Igniter.Project.Formatter","doc":"Codemods and utilities for interacting with `.formatter.exs` files","ref":"Igniter.Project.Formatter.html"},{"type":"function","title":"Igniter.Project.Formatter.add_formatter_plugin/2","doc":"Adds a new plugin to the list of plugins in the root `.formatter.exs`","ref":"Igniter.Project.Formatter.html#add_formatter_plugin/2"},{"type":"function","title":"Igniter.Project.Formatter.import_dep/2","doc":"Adds a new dep to the list of imported deps in the root `.formatter.exs`","ref":"Igniter.Project.Formatter.html#import_dep/2"},{"type":"module","title":"Igniter.Project.IgniterConfig","doc":"Tools for reading and modifying the `.igniter.exs` file.\n\nThe command `mix igniter.setup` will generate this file, as well\nas keep it up to date with any new configurations. You can run this\ncommand at any time to update the file without overriding your own config.\n\nIf the file does not exist, all values are considered to have their default value.","ref":"Igniter.Project.IgniterConfig.html"},{"type":"module","title":"Options - Igniter.Project.IgniterConfig","doc":"* `:module_location` - - `:outside_matching_folder`, modules will be placed in a folder exactly matching their path.\n  - `:inside_matching_folder`, modules who's name matches an existing folder will be placed inside that folder,\n     or moved there if the folder is created. The default value is `:outside_matching_folder`.\n\n* `:source_folders` (list of `t:String.t/0`) - A list of folders to manage elixir files in. The default value is `[\"lib\", \"test/support\"]`.\n\n* `:dont_move_files` (list of `t:term/0`) - A list of strings or regexes. Any files that equal (in the case of strings) or match (in the case of regexes) will not be moved. The default value is `[]`.","ref":"Igniter.Project.IgniterConfig.html#module-options"},{"type":"function","title":"Igniter.Project.IgniterConfig.get/2","doc":"","ref":"Igniter.Project.IgniterConfig.html#get/2"},{"type":"function","title":"Igniter.Project.IgniterConfig.setup/1","doc":"","ref":"Igniter.Project.IgniterConfig.html#setup/1"},{"type":"module","title":"Igniter.Project.Test","doc":"Codemods and utilities for interacting with test and test support files","ref":"Igniter.Project.Test.html"},{"type":"function","title":"Igniter.Project.Test.ensure_test_support/1","doc":"","ref":"Igniter.Project.Test.html#ensure_test_support/1"},{"type":"module","title":"Igniter.Util.Debug","doc":"Tools for debugging zippers.","ref":"Igniter.Util.Debug.html"},{"type":"function","title":"Igniter.Util.Debug.code_at_node/1","doc":"Returns the formatted code at the node of the zipper to the console","ref":"Igniter.Util.Debug.html#code_at_node/1"},{"type":"function","title":"Igniter.Util.Debug.puts_ast_at_node/1","doc":"Puts the ast at the node of the zipper to the console","ref":"Igniter.Util.Debug.html#puts_ast_at_node/1"},{"type":"function","title":"Igniter.Util.Debug.puts_code_at_node/1","doc":"Puts the formatted code at the node of the zipper to the console","ref":"Igniter.Util.Debug.html#puts_code_at_node/1"},{"type":"module","title":"Igniter.Util.Version","doc":"Utilities for working versions and version requirements","ref":"Igniter.Util.Version.html"},{"type":"function","title":"Igniter.Util.Version.version_string_to_general_requirement/1","doc":"","ref":"Igniter.Util.Version.html#version_string_to_general_requirement/1"},{"type":"function","title":"Igniter.Util.Version.version_string_to_general_requirement!/1","doc":"Provides a general requirement for a given version string.\n\nFor example\n\n`3.1.2` would be `~> 3.0`\nand\n`0.2.4` would be `~> 0.2`","ref":"Igniter.Util.Version.html#version_string_to_general_requirement!/1"},{"type":"task","title":"mix igniter.install","doc":"Install a package or packages, and run any associated installers.","ref":"Mix.Tasks.Igniter.Install.html"},{"type":"task","title":"Args - mix igniter.install","doc":"mix igniter.install package1 package2 package3","ref":"Mix.Tasks.Igniter.Install.html#module-args"},{"type":"task","title":"Package formats - mix igniter.install","doc":"* `package` - The latest version of the package will be installed, pinned at the\n   major version, or minor version if there is no major version yet.\n* `package@version` - The package will be installed at the specified version.\n   If the version given is generic, like `3.0`, it will be pinned as described above.\n   if it is specific, like `3.0.1`, it will be pinned at that *exact* version with `==`.\n* `package@git:git_url` - The package will be installed from the specified git url.\n* `package@github:project/repo` - The package will be installed from the specified github repo.\n* `package@path:path/to/dep` - The package will be installed from the specified path.","ref":"Mix.Tasks.Igniter.Install.html#module-package-formats"},{"type":"task","title":"Switches - mix igniter.install","doc":"* `--dry-run` - Run the task without making any changes.\n* `--yes` - Automatically answer yes to any prompts.\n* `--example` - Request that installed packages include initial example code.","ref":"Mix.Tasks.Igniter.Install.html#module-switches"},{"type":"task","title":"mix igniter.move_files","doc":"Moves any relavant files to their 'correct' location.","ref":"Mix.Tasks.Igniter.MoveFiles.html"},{"type":"function","title":"Mix.Tasks.Igniter.MoveFiles.igniter/2","doc":"","ref":"Mix.Tasks.Igniter.MoveFiles.html#igniter/2"},{"type":"task","title":"mix igniter.setup","doc":"Creates or updates a .igniter.exs file, used to configure Igniter for end user's preferences.","ref":"Mix.Tasks.Igniter.Setup.html"},{"type":"function","title":"Mix.Tasks.Igniter.Setup.igniter/2","doc":"","ref":"Mix.Tasks.Igniter.Setup.html#igniter/2"},{"type":"extras","title":"Home","doc":"[![CI](https://github.com/ash-project/igniter/actions/workflows/elixir.yml/badge.svg)](https://github.com/ash-project/igniter/actions/workflows/elixir.yml)\n[![Hex version badge](https://img.shields.io/hexpm/v/igniter.svg)](https://hex.pm/packages/igniter)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/igniter)\n\n# Igniter\n\nIgniter is a code generation and project patching framework.\n\nFor library authors, this is a tool kit for writing smarter generators that can semantically modify existing files, and all sorts of useful tools for doing so.\n\nFor end-users, this means `mix igniter.install  `, which will _add it to your mix.exs automatically_ and then run that library's installer if it has one. Even when libraries don't have an installer, or use igniter, this behavior makes it useful to keep around.","ref":"readme.html"},{"type":"extras","title":"State of the project - Home","doc":"This project is in early beta. There is _so much to add_! There are lots of DX/UX things to improve, but it does already provide some great utility. Contributions welcome!","ref":"readme.html#state-of-the-project"},{"type":"extras","title":"Limitations - Home","doc":"Right now, all files that are touched are formatted in their entirety. This may be a deal breaker for some users. I believe that we can solve this without changing the fundemental design of the project, but it is not a high priority in the early stages.","ref":"readme.html#limitations"},{"type":"extras","title":"Installation - Home","doc":"Igniter can be added to an existing elixir project by adding it to your dependencies:\n\n```elixir\n{:igniter, \"~> 0.1\"}\n```\n\nYou can also generate new projects with igniter preinstalled, and run installers in the same command.\n\nFirst, install the archive:\n\n```elixir\nmix archive.install hex igniter_new\n```\n\nThen you can run `mix igniter.new`\n\n```\nmix igniter.new app_name --install ash\n```\n\nOr if you want to use a different project creator, specify the mix task name with the `--with` flag. Any arguments will be passed through to that task, with the exception of `--install` and `--example`.\n\n```\nmix igniter.new app_name --install ash --with phx.new --no-ecto\n```","ref":"readme.html#installation"},{"type":"extras","title":"Patterns - Home","doc":"Mix tasks built with igniter are both individually callable, _and_ composable. This means that tasks can call eachother, and also end users can create and customize their own generators composing existing tasks.","ref":"readme.html#patterns"},{"type":"extras","title":"Installers - Home","doc":"Igniter will look for a task called ` .install` when the user runs `mix igniter.install  `, and will run it after installing and fetching dependencies.","ref":"readme.html#installers"},{"type":"extras","title":"Generators/Patchers - Home","doc":"These can be run like any other mix task, or composed together. For example, lets say that you wanted to have your own `Ash.Resource` generator, that starts with the default `mix ash.gen.resource` task, but then adds or modifies files:\n\n```elixir\n# in lib/mix/tasks/my_app.gen.resource.ex\ndefmodule Mix.Tasks.MyApp.Gen.Resource do\n  use Igniter.Mix.Task\n\n  def igniter(igniter, [resource | _] = argv) do\n    resource = Igniter.Code.Module.parse(resource)\n    my_special_thing = Module.concat([resource, SpecialThing])\n    location = Igniter.Code.Module.proper_location(my_special_thing)\n\n    igniter\n    |> Igniter.compose_task(\"ash.gen.resource\", argv)\n    |> Igniter.create_new_elixir_file(location, \"\"\"\n    defmodule #{inspect(my_special_thing)} do\n      # this is the special thing for #{inspect()}\n    end\n    \"\"\")\n  end\nend\n```","ref":"readme.html#generators-patchers"},{"type":"extras","title":"Writing Generators","doc":"# Writing Generators\n\nIn `Igniter`, generators are done as a wrapper around `Mix.Task`, allowing them to be called individually or composed as part of a task. Since an example is worth a thousand words, lets take a look at an example that generates a file and ensures a configuration is set in the user's `config.exs`.\n\n```elixir\n# lib/mix/tasks/your_lib.gen.your_thing.ex\ndefmodule Mix.Tasks.YourLib.Gen.YourThing do\n  use Igniter.Mix.Task\n\n  def igniter(igniter, [module_name | _ ] = argv) do\n    module_name = Igniter.Module.parse(module_name)\n    path = Igniter.Module.proper_location(module_name)\n    app_name = Igniter.Application.app_name()\n\n    igniter\n    |> Igniter.create_new_elixir_file(path, \"\"\"\n    defmodule #{inspect(module_name)} do\n      use YourLib.Thing\n\n      ...some_code\n    end\n    \"\"\")\n    |> Igniter.Project.Config.configure(\n      \"config.exs\",\n      app_name,\n      [:list_of_things],\n      [module_name],\n      &Igniter.Code.List.prepend_new_to_list(&1, module_name)\n    )\n  end\nend\n```\n\nNow, your users can run\n\n`mix your_lib.gen.your_thing MyApp.MyModuleName`\n\nand it will present them with a diff, creating a new file and updating their `config.exs`.\n\nAdditionally, other generators can \"compose\" this generator using `Igniter.compose_task/3`\n\n```elixir\nigniter\n|> Igniter.compose_task(Mix.Tasks.YourLib.Gen.YourThing, [\"MyApp.MyModuleName\"])\n|> Igniter.compose_task(Mix.Tasks.YourLib.Gen.YourThing, [\"MyApp.SomeOtherName\"])\n```","ref":"writing-generators.html"},{"type":"extras","title":"Writing a library installer - Writing Generators","doc":"Igniter will look for a mix task called `your_library.install` when a user runs `mix igniter.install your_library`. As long as it has the correct name, it will be run automatically as part of installation!","ref":"writing-generators.html#writing-a-library-installer"},{"type":"extras","title":"Navigating the Igniter Codebase - Writing Generators","doc":"A large part of writing generators with igniter is leveraging our built-in suite of tools for working with zippers and AST, as well as our off-the-shelf patchers for making project modifications. The codebase is split up into four primary divisions:\n\n- `Igniter.Project.*` - project-level, off-the-shelf patchers\n- `Igniter.Code.*` - working with zippers and manipulating source code\n- `Ignier.Mix.*` - mix tasks, tools for writing igniter mix tasks\n- `Igniter.Util.*` - various utilities and helpers","ref":"writing-generators.html#navigating-the-igniter-codebase"},{"type":"extras","title":"Configuring Igniter","doc":"# Configuring Igniter\n\nThis guide is for those who are _end-users_ of igniter, for example, using the generators provided by a library that are backed by igniter.","ref":"configuring-igniter.html"},{"type":"extras","title":"Setting up igniter - Configuring Igniter","doc":"Use `mix igniter.setup` to create a `.igniter.exs` file in your project root. This file configures igniter for your project. You can run this command repeatedly to keep the file up to date over time.\n\nSee the documentation in `Igniter.Project.IgniterConfig` for available configuration.","ref":"configuring-igniter.html#setting-up-igniter"},{"type":"extras","title":"Moving files - Configuring Igniter","doc":"One available configuration is `module_location`. This configuration dictates where modules are placed when there is a folder that exactly matches their module name. There are two available strategies for this, and with igniter not only can you change your mind, but you can actually _move back and forth_ between each strategy. To move any modules to their rightful place, use `mix igniter.move_files`.\n\n>","ref":"configuring-igniter.html#moving-files"},{"type":"extras","title":"Only for matching modules {: .tip} - Configuring Igniter","doc":">\n> The following rules are _only applied_ when a top-level module is defined in the file. If it is not, then the file will always be left exactly where it is. It is generally considered best-practice to define one top-level module per file.\n\n## `:outside_matching_folder`\n\nThe \"standard\" way to place a module is to place it in a folder path that exactly matches its module name, inside of `lib/`. For example, a module named `MyApp.MyModule` would be placed in `lib/my_app/my_module.ex`.\n\nUse the default `:outside_matching_folder` to follow this convention in all cases.\n\n## `:inside_matching_folder`\n\nWhat some people don't like about the previously described strategy is that it can split up related modules. For example:\n\n```\nlib/\n└── my_app/\n    ├── accounts/\n    │   ├── user.ex\n    │   ├── organization.ex\n    ├── social/\n    │   ├── post.ex\n    │   ├── comment.ex\n    ├── accounts.ex # <- This feels to some like it should be in `/accounts`\n    └── social.ex\n```\n\nThey would prefer to put that leaf-node module in its matching folder _if it exists_, and otherwise follow the original convention if not.\n\n```\nlib/\n└── my_app/\n    ├── accounts/\n    │   ├── user.ex\n    │   ├── organization.ex\n    │   ├── accounts.ex\n    ├── social/\n    │   ├── post.ex\n    │   ├── comment.ex\n    │   └── social.ex\n```","ref":"configuring-igniter.html#only-for-matching-modules-tip"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.2.11](https://github.com/ash-project/igniter/compare/v0.2.10...v0.2.11) (2024-07-10)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* prevent crash on specific cases with `igniter.new`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* more consistent initial impl of `elixirc_paths`\n\n* support :kind in find_and_update_or_create_module/5 (#38)\n\n## [v0.2.10](https://github.com/ash-project/igniter/compare/v0.2.9...v0.2.10) (2024-07-10)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* ensure `test/support` is in elixirc paths automatically when necessary\n\n## [v0.2.9](https://github.com/ash-project/igniter/compare/v0.2.8...v0.2.9) (2024-07-09)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* simplify how we get tasks to run\n\n* don't try to format after editing `mix.exs`\n\n## [v0.2.8](https://github.com/ash-project/igniter/compare/v0.2.7...v0.2.8) (2024-07-09)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* fix deps compilation issues by vendoring `deps.compile`\n\n* honor `--yes` flag when installing deps always","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* small tweaks to output\n\n## [v0.2.7](https://github.com/ash-project/igniter/compare/v0.2.6...v0.2.7) (2024-07-09)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* remove shortnames for global options, to reduce conflicts\n\n* remove erroneous warning while composing tasks\n\n* pass file_path to `ensure_default_configs_exist` (#36)\n\n* preserve original ordering in Util.Install (#33)\n\n* include only \"mix.exs\" in the actual run in apply_and_fetch_dependencies (#32)\n\n* always return {:ok, zipper} in append_new_to_list/2 (#31)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* support an optional append? flag for add_dep/3 (#34)\n\n* add `add_dep/2-3`, that accepts a full dep specification\n\n* deprecate `add_dependency/3-4`\n\n* make module moving much smarter\n\n* add configurations for not moving certain modules\n\n* make `source_folders` configurable\n\n## [v0.2.6](https://github.com/ash-project/igniter/compare/v0.2.5...v0.2.6) (2024-07-02)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* properly find nested modules again\n\n* make igniter tests much faster by not searching our own project\n\n* add `include_all_elixir_files/1`\n\n* add `module_exists?/2`\n\n* add `find_and_update_module/3`\n\n* only require rejecting mix deps.get one time & remember that choice\n\n* simpler messages signaling a mix deps.get\n\n## [v0.2.5](https://github.com/ash-project/igniter/compare/v0.2.4...v0.2.5) (2024-07-02)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* `move_modules` -> `move_files`\n\n* move some files around and update config names\n\n* use `%Info{}` structs to compose and plan nested installers\n\n* add Igniter.apply_and_fetch_dependencies/1 and Igniter.has_changes?/1 (#28)\n\n* rename option_schema/2 -> info/2\n\n* only create default configs if an env-specific config is created\n\n## [v0.2.4](https://github.com/ash-project/igniter/compare/v0.2.3...v0.2.4) (2024-06-28)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* fix match error in `append_new_to_list`\n\n* version string splitting (#25)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* add an optional path argument to `find_and_update_or_create_module/5`\n\n* add `option_schema/2` callback to `Igniter.Mix.Task`\n\n* `Module.find_and_update_or_create_module`\n\n* add a way to move files\n\n* add `.igniter.exs` file, and `mix igniter.setup` to create it\n\n* move files to configured location based on changes\n\n* add fallback to compose_task (#19)\n\n* add proper_test_support_location/1 (#18)\n\n* add proper_test_location/1 (#17)\n\n## [v0.2.3](https://github.com/ash-project/igniter/compare/v0.2.2...v0.2.3) (2024-06-21)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* use `override: true` for git/github deps as well\n\n## [v0.2.2](https://github.com/ash-project/igniter/compare/v0.2.1...v0.2.2) (2024-06-21)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* don't show unnecessary diff output\n\n* don't compile before fetching deps\n\n## [v0.2.1](https://github.com/ash-project/igniter/compare/v0.2.0...v0.2.1) (2024-06-21)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* workaround trailing comment issues w/ sourceror\n\n* support `--with` option in `igniter.new`\n\n## [v0.2.0](https://github.com/ash-project/igniter/compare/v0.1.8...v0.2.0) (2024-06-20)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* make installer use `override: true` on local dependency\n\n* ensure dependencies are compiled after `mix deps.get`\n\n* use warnings instead of errors for better UX\n\n* move proejct related things to `Project` namespace\n\n## [v0.1.8](https://github.com/ash-project/igniter/compare/v0.1.7...v0.1.8) (2024-06-19)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* update spitfire for env fix","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* rename `env_at_cursor` to `current_env`\n\n* improve marshalling of spitfire env to macro env\n\n* show warning when adding dependencies by default\n\n## [v0.1.7](https://github.com/ash-project/igniter/compare/v0.1.6...v0.1.7) (2024-06-14)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* various restructurings and improvements across the board\n\n* use `Spitfire` to ensure that aliases are considered when comparing modules\n\n* use `Spitfire` to *use* any existing aliases when inserting code\n\n* use `Zipper.topmost` to power new `Spitfire`-related features\n\n## [v0.1.6](https://github.com/ash-project/igniter/compare/v0.1.5...v0.1.6) (2024-06-13)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* patch formatter fix, to be removed later when rewrite PR is merged\n\n* properly find functions in scope\n\n## [v0.1.5](https://github.com/ash-project/igniter/compare/v0.1.4...v0.1.5) (2024-06-13)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* Igniter.Code.Common.with/2 was not properly merging with original zipper\n\n## [v0.1.4](https://github.com/ash-project/igniter/compare/v0.1.3...v0.1.4) (2024-06-13)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* use `path:` prefix instead of `local:`\n\n## [v0.1.3](https://github.com/ash-project/igniter/compare/v0.1.2...v0.1.3) (2024-06-13)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements: - Change Log","doc":"* support space-separated installers\n\n## [v0.1.2](https://github.com/ash-project/igniter/compare/v0.1.1...v0.1.2) (2024-06-13)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* remove unsupportable package installation symbols\n\n* don't run `mix deps.get` if dependency changes are aborted\n\n## [v0.1.1](https://github.com/ash-project/igniter/compare/v0.1.0...v0.1.1) (2024-06-13)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* always format the file even if no `.formatter.exs` exists\n\n## [v0.1.0](https://github.com/ash-project/igniter/compare/v0.1.0...v0.1.0) (2024-06-13)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* handle existing deps when they are not local properly","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* ignore installer tasks that are not igniter tasks\n\n* draw the rest of the owl\n\n* add installer archive\n\n* more module helpers\n\n* wrap code in `==code==` so you can tell what is being `puts`\n\n* add CI/build and get it passing locally","ref":"changelog.html#improvements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}